// src/api.ts
import globalAxios2 from "axios";

// src/base.ts
import globalAxios from "axios";
var BASE_PATH = "https://users.dopt.com".replace(/\/+$/, "");
var BaseAPI = class {
  constructor(configuration, basePath = BASE_PATH, axios = globalAxios) {
    this.basePath = basePath;
    this.axios = axios;
    if (configuration) {
      this.configuration = configuration;
      this.basePath = configuration.basePath || this.basePath;
    }
  }
  configuration;
};
var RequiredError = class extends Error {
  constructor(field, msg) {
    super(msg);
    this.field = field;
  }
  name = "RequiredError";
};

// src/common.ts
var DUMMY_BASE_URL = "https://example.com";
var assertParamExists = function(functionName, paramName, paramValue) {
  if (paramValue === null || paramValue === void 0) {
    throw new RequiredError(paramName, `Required parameter ${paramName} was null or undefined when calling ${functionName}.`);
  }
};
var setApiKeyToObject = async function(object, keyParamName, configuration) {
  if (configuration && configuration.apiKey) {
    const localVarApiKeyValue = typeof configuration.apiKey === "function" ? await configuration.apiKey(keyParamName) : await configuration.apiKey;
    object[keyParamName] = localVarApiKeyValue;
  }
};
function setFlattenedQueryParams(urlSearchParams, parameter, key = "") {
  if (typeof parameter === "object") {
    if (Array.isArray(parameter)) {
      parameter.forEach((item) => setFlattenedQueryParams(urlSearchParams, item, key));
    } else {
      Object.keys(parameter).forEach(
        (currentKey) => setFlattenedQueryParams(urlSearchParams, parameter[currentKey], `${key}${key !== "" ? "." : ""}${currentKey}`)
      );
    }
  } else {
    if (urlSearchParams.has(key)) {
      urlSearchParams.append(key, parameter);
    } else {
      urlSearchParams.set(key, parameter);
    }
  }
}
var setSearchParams = function(url, ...objects) {
  const searchParams = new URLSearchParams(url.search);
  setFlattenedQueryParams(searchParams, objects);
  url.search = searchParams.toString();
};
var serializeDataIfNeeded = function(value, requestOptions, configuration) {
  const nonString = typeof value !== "string";
  const needsSerialization = nonString && configuration && configuration.isJsonMime ? configuration.isJsonMime(requestOptions.headers["Content-Type"]) : nonString;
  return needsSerialization ? JSON.stringify(value !== void 0 ? value : {}) : value || "";
};
var toPathString = function(url) {
  return url.pathname + url.search + url.hash;
};
var createRequestFunction = function(axiosArgs, globalAxios3, BASE_PATH2, configuration) {
  return (axios = globalAxios3, basePath = BASE_PATH2) => {
    const axiosRequestArgs = { ...axiosArgs.options, url: (configuration?.basePath || basePath) + axiosArgs.url };
    return axios.request(axiosRequestArgs);
  };
};

// src/api.ts
var IdentifyApiAxiosParamCreator = function(configuration) {
  return {
    identify: async (identifier, requestBody, options = {}) => {
      assertParamExists("identify", "identifier", identifier);
      const localVarPath = `/identify/{identifier}`.replace(`{${"identifier"}}`, encodeURIComponent(String(identifier)));
      const localVarUrlObj = new URL(localVarPath, DUMMY_BASE_URL);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = { method: "POST", ...baseOptions, ...options };
      const localVarHeaderParameter = {};
      const localVarQueryParameter = {};
      await setApiKeyToObject(localVarHeaderParameter, "X-Api-Key", configuration);
      localVarHeaderParameter["Content-Type"] = "application/json";
      setSearchParams(localVarUrlObj, localVarQueryParameter);
      let headersFromBaseOptions = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      localVarRequestOptions.headers = { ...localVarHeaderParameter, ...headersFromBaseOptions, ...options.headers };
      localVarRequestOptions.data = serializeDataIfNeeded(requestBody, localVarRequestOptions, configuration);
      return {
        url: toPathString(localVarUrlObj),
        options: localVarRequestOptions
      };
    },
    identifyBulk: async (identifyBulkRequestBodyInner, options = {}) => {
      const localVarPath = `/identify/bulk`;
      const localVarUrlObj = new URL(localVarPath, DUMMY_BASE_URL);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = { method: "POST", ...baseOptions, ...options };
      const localVarHeaderParameter = {};
      const localVarQueryParameter = {};
      await setApiKeyToObject(localVarHeaderParameter, "X-Api-Key", configuration);
      localVarHeaderParameter["Content-Type"] = "application/json";
      setSearchParams(localVarUrlObj, localVarQueryParameter);
      let headersFromBaseOptions = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      localVarRequestOptions.headers = { ...localVarHeaderParameter, ...headersFromBaseOptions, ...options.headers };
      localVarRequestOptions.data = serializeDataIfNeeded(identifyBulkRequestBodyInner, localVarRequestOptions, configuration);
      return {
        url: toPathString(localVarUrlObj),
        options: localVarRequestOptions
      };
    },
    identifySegment: async (identifySegmentRequestBody, options = {}) => {
      const localVarPath = `/identify/segment`;
      const localVarUrlObj = new URL(localVarPath, DUMMY_BASE_URL);
      let baseOptions;
      if (configuration) {
        baseOptions = configuration.baseOptions;
      }
      const localVarRequestOptions = { method: "POST", ...baseOptions, ...options };
      const localVarHeaderParameter = {};
      const localVarQueryParameter = {};
      await setApiKeyToObject(localVarHeaderParameter, "X-Api-Key", configuration);
      localVarHeaderParameter["Content-Type"] = "application/json";
      setSearchParams(localVarUrlObj, localVarQueryParameter);
      let headersFromBaseOptions = baseOptions && baseOptions.headers ? baseOptions.headers : {};
      localVarRequestOptions.headers = { ...localVarHeaderParameter, ...headersFromBaseOptions, ...options.headers };
      localVarRequestOptions.data = serializeDataIfNeeded(identifySegmentRequestBody, localVarRequestOptions, configuration);
      return {
        url: toPathString(localVarUrlObj),
        options: localVarRequestOptions
      };
    }
  };
};
var IdentifyApiFp = function(configuration) {
  const localVarAxiosParamCreator = IdentifyApiAxiosParamCreator(configuration);
  return {
    async identify(identifier, requestBody, options) {
      const localVarAxiosArgs = await localVarAxiosParamCreator.identify(identifier, requestBody, options);
      return createRequestFunction(localVarAxiosArgs, globalAxios2, BASE_PATH, configuration);
    },
    async identifyBulk(identifyBulkRequestBodyInner, options) {
      const localVarAxiosArgs = await localVarAxiosParamCreator.identifyBulk(identifyBulkRequestBodyInner, options);
      return createRequestFunction(localVarAxiosArgs, globalAxios2, BASE_PATH, configuration);
    },
    async identifySegment(identifySegmentRequestBody, options) {
      const localVarAxiosArgs = await localVarAxiosParamCreator.identifySegment(identifySegmentRequestBody, options);
      return createRequestFunction(localVarAxiosArgs, globalAxios2, BASE_PATH, configuration);
    }
  };
};
var IdentifyApiFactory = function(configuration, basePath, axios) {
  const localVarFp = IdentifyApiFp(configuration);
  return {
    identify(identifier, requestBody, options) {
      return localVarFp.identify(identifier, requestBody, options).then((request) => request(axios, basePath));
    },
    identifyBulk(identifyBulkRequestBodyInner, options) {
      return localVarFp.identifyBulk(identifyBulkRequestBodyInner, options).then((request) => request(axios, basePath));
    },
    identifySegment(identifySegmentRequestBody, options) {
      return localVarFp.identifySegment(identifySegmentRequestBody, options).then((request) => request(axios, basePath));
    }
  };
};
var IdentifyApi = class extends BaseAPI {
  identify(identifier, requestBody, options) {
    return IdentifyApiFp(this.configuration).identify(identifier, requestBody, options).then((request) => request(this.axios, this.basePath));
  }
  identifyBulk(identifyBulkRequestBodyInner, options) {
    return IdentifyApiFp(this.configuration).identifyBulk(identifyBulkRequestBodyInner, options).then((request) => request(this.axios, this.basePath));
  }
  identifySegment(identifySegmentRequestBody, options) {
    return IdentifyApiFp(this.configuration).identifySegment(identifySegmentRequestBody, options).then((request) => request(this.axios, this.basePath));
  }
};

// src/configuration.ts
var Configuration = class {
  apiKey;
  username;
  password;
  accessToken;
  basePath;
  baseOptions;
  formDataCtor;
  constructor(param = {}) {
    this.apiKey = param.apiKey;
    this.username = param.username;
    this.password = param.password;
    this.accessToken = param.accessToken;
    this.basePath = param.basePath;
    this.baseOptions = param.baseOptions;
    this.formDataCtor = param.formDataCtor;
  }
  isJsonMime(mime) {
    const jsonMime = new RegExp("^(application/json|[^;/ 	]+/[^;/ 	]+[+]json)[ 	]*(;.*)?$", "i");
    return mime !== null && (jsonMime.test(mime) || mime.toLowerCase() === "application/json-patch+json");
  }
};
export {
  Configuration,
  IdentifyApi,
  IdentifyApiAxiosParamCreator,
  IdentifyApiFactory,
  IdentifyApiFp
};
